ConfigBuilder

Struct ConfigBuilder 

pub struct ConfigBuilder { /* private fields */ }
Builder for Config.

Implementations

Source

impl ConfigBuilder

pub fn path_policy(self, policy: impl PathPolicy) -> Self

Set the path access policy.

Default: Unrestricted (no checks).

pub fn http_policy(self, policy: impl HttpPolicy) -> Self

Set the HTTP URL access policy.

Default: Unrestricted (no checks).

pub fn env_policy(self, policy: impl EnvPolicy) -> Self

Set the environment variable access policy.

Default: Unrestricted (no checks).

pub fn llm_policy(self, policy: impl LlmPolicy) -> Self

Set the LLM request policy.

Default: Unrestricted (no checks).

pub fn llm_default_timeout_secs(self, secs: u64) -> Self

Default timeout for LLM requests in seconds.

Default: 120.

pub fn llm_max_response_bytes(self, bytes: u64) -> Self

Maximum LLM response body size in bytes.

Default: 10_485_760 (10 MiB).

pub fn llm_max_batch_concurrency(self, n: usize) -> Self

Maximum number of concurrent threads for llm.batch.

Default: 8.

pub fn max_read_bytes(self, bytes: u64) -> Self

Maximum number of bytes fs.read and fs.read_binary will load.

Default: None (no limit). When set, an error is returned if the file size exceeds this value.

pub fn max_walk_depth(self, depth: usize) -> Self

Maximum directory depth for fs.walk.

Default: 256.

pub fn max_walk_entries(self, entries: usize) -> Self

Maximum number of entries returned by fs.walk and fs.glob.

Default: 10_000.

pub fn max_json_depth(self, depth: usize) -> Self

Maximum nesting depth for JSON encode/decode.

Default: 128.

pub fn http_timeout(self, timeout: Duration) -> Self

Default timeout for HTTP requests.

Default: 30 seconds.

pub fn max_response_bytes(self, bytes: u64) -> Self

Maximum HTTP response body size in bytes.

Default: 10_485_760 (10 MiB).

pub fn max_sleep_secs(self, secs: f64) -> Self

Maximum duration for time.sleep in seconds.

Default: 86400.0 (1 day).

build returns an error if the value is NaN, infinite, or negative.

pub fn build(self) -> Result<Config, ConfigError>

Finalise the configuration.

Returns Err if any configured value is invalid.